@@ -1,4 +1,4 @@
-/* (C)opyright MMVI Anselm R. Garbe <garbeam at gmail dot com>
+/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  */
 #include "dwm.h"
@@ -60,12 +60,6 @@ xerrordummy(Display *dsply, XErrorEvent *ee) {
 
 /* extern functions */
 
-void
-ban(Client *c) {
-	XMoveWindow(dpy, c->win, c->x + 2 * sw, c->y);
-	XMoveWindow(dpy, c->twin, c->tx + 2 * sw, c->ty);
-}
-
 void
 configure(Client *c) {
 	XEvent synev;
@@ -96,7 +90,7 @@ focus(Client *c) {
 		sel = c;
 		if(old) {
 			grabbuttons(old, False);
-			drawtitle(old);
+			XSetWindowBorder(dpy, old->win, dc.norm[ColBorder]);
 		}
 	}
 	if(c) {
@@ -104,11 +98,12 @@ focus(Client *c) {
 		c->snext = stack;
 		stack = c;
 		grabbuttons(c, True);
-		drawtitle(c);
+		XSetWindowBorder(dpy, c->win, dc.sel[ColBorder]);
 		XSetInputFocus(dpy, c->win, RevertToPointerRoot, CurrentTime);
 	}
 	else
 		XSetInputFocus(dpy, root, RevertToPointerRoot, CurrentTime);
+	drawstatus();
 }
 
 Client *
@@ -121,16 +116,6 @@ getclient(Window w) {
 	return NULL;
 }
 
-Client *
-getctitle(Window w) {
-	Client *c;
-
-	for(c = clients; c; c = c->next)
-		if(c->twin == w)
-			return c;
-	return NULL;
-}
-
 void
 killclient(Arg *arg) {
 	if(!sel)
@@ -145,18 +130,16 @@ void
 manage(Window w, XWindowAttributes *wa) {
 	Client *c;
 	Window trans;
-	XSetWindowAttributes twa;
 
 	c = emallocz(sizeof(Client));
 	c->tags = emallocz(ntags * sizeof(Bool));
 	c->win = w;
 	c->border = 0;
-	c->x = c->tx = wa->x;
-	c->y = c->ty = wa->y;
-	c->w = c->tw = wa->width;
+	c->x = wa->x;
+	c->y = wa->y;
+	c->w = wa->width;
 	c->h = wa->height;
-	c->th = bh;
-	updatesize(c);
+	updatesizehints(c);
 	if(c->x + c->w + 2 * BORDERPX > sw)
 		c->x = sw - c->w - 2 * BORDERPX;
 	if(c->x < sx)
@@ -169,27 +152,18 @@ manage(Window w, XWindowAttributes *wa) {
 	XSelectInput(dpy, c->win,
 		StructureNotifyMask | PropertyChangeMask | EnterWindowMask);
 	XGetTransientForHint(dpy, c->win, &trans);
-	twa.override_redirect = 1;
-	twa.background_pixmap = ParentRelative;
-	twa.event_mask = ExposureMask | EnterWindowMask;
-	c->twin = XCreateWindow(dpy, root, c->tx, c->ty, c->tw, c->th,
-			0, DefaultDepth(dpy, screen), CopyFromParent,
-			DefaultVisual(dpy, screen),
-			CWOverrideRedirect | CWBackPixmap | CWEventMask, &twa);
 	grabbuttons(c, False);
 	updatetitle(c);
 	settags(c, getclient(trans));
 	if(!c->isfloat)
 		c->isfloat = trans || c->isfixed;
-	resizetitle(c);
 	if(clients)
 		clients->prev = c;
 	c->next = clients;
 	c->snext = stack;
 	stack = clients = c;
-	ban(c);
+	XMoveWindow(dpy, c->win, c->x + 2 * sw, c->y);
 	XMapWindow(dpy, c->win);
-	XMapWindow(dpy, c->twin);
 	if(isvisible(c))
 		focus(c);
 	arrange();
@@ -228,7 +202,6 @@ resize(Client *c, Bool sizehints, Corner sticky) {
 		c->x = sw - c->w;
 	if(c->y > sh)
 		c->y = sh - c->h;
-	resizetitle(c);
 	wc.x = c->x;
 	wc.y = c->y;
 	wc.width = c->w;
@@ -243,20 +216,7 @@ resize(Client *c, Bool sizehints, Corner sticky) {
 }
 
 void
-resizetitle(Client *c) {
-	c->tw = textw(c->name);
-	if(c->tw > c->w)
-		c->tw = c->w + 2 * BORDERPX;
-	c->tx = c->x + c->w - c->tw + 2 * BORDERPX;
-	c->ty = c->y;
-	if(isvisible(c))
-		XMoveResizeWindow(dpy, c->twin, c->tx, c->ty, c->tw, c->th);
-	else
-		XMoveResizeWindow(dpy, c->twin, c->tx + 2 * sw, c->ty, c->tw, c->th);
-}
-
-void
-updatesize(Client *c) {
+updatesizehints(Client *c) {
 	long msize;
 	XSizeHints size;
 
@@ -331,7 +291,6 @@ unmanage(Client *c) {
 		focus(nc);
 	}
 	XUngrabButton(dpy, AnyButton, AnyModifier, c->win);
-	XDestroyWindow(dpy, c->twin);
 	free(c->tags);
 	free(c);
 	XSync(dpy, False);
