@@ -1,4 +1,4 @@
-/* (C)opyright MMIV-MMVI Anselm R. Garbe <garbeam at gmail dot com>
+/* (C)opyright MMIV-MMVII Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  */
 #include "dwm.h"
@@ -97,15 +97,6 @@ drawtext(const char *text, unsigned long col[ColLast], Bool filledsquare, Bool e
 
 /* extern */
 
-void
-drawall(void) {
-	Client *c;
-
-	for(c = clients; c; c = getnext(c->next))
-		drawtitle(c);
-	drawstatus();
-}
-
 void
 drawstatus(void) {
 	int i, x;
@@ -120,37 +111,20 @@ drawstatus(void) {
 		dc.x += dc.w;
 	}
 	dc.w = bmw;
-	drawtext(arrange == dofloat ?  FLOATSYMBOL : TILESYMBOL, dc.status, False, False);
+	drawtext(arrange == dofloat ? FLOATSYMBOL : TILESYMBOL, dc.norm, False, False);
 	x = dc.x + dc.w;
 	dc.w = textw(stext);
-	dc.x = bw - dc.w;
+	dc.x = sw - dc.w;
 	if(dc.x < x) {
 		dc.x = x;
-		dc.w = bw - x;
+		dc.w = sw - x;
 	}
-	drawtext(stext, dc.status, False, False);
+	drawtext(stext, dc.norm, False, False);
 	if((dc.w = dc.x - x) > bh) {
 		dc.x = x;
 		drawtext(sel ? sel->name : NULL, sel ? dc.sel : dc.norm, False, False);
 	}
-	XCopyArea(dpy, dc.drawable, barwin, dc.gc, 0, 0, bw, bh, 0, 0);
-	XSync(dpy, False);
-}
-
-void
-drawtitle(Client *c) {
-	if(c == sel && issel) {
-		drawstatus();
-		XUnmapWindow(dpy, c->twin);
-		XSetWindowBorder(dpy, c->win, dc.sel[ColBG]);
-		return;
-	}
-	XSetWindowBorder(dpy, c->win, dc.norm[ColBG]);
-	XMapWindow(dpy, c->twin);
-	dc.x = dc.y = 0;
-	dc.w = c->tw;
-	drawtext(c->name, dc.norm, False,False);
-	XCopyArea(dpy, dc.drawable, c->twin, dc.gc, 0, 0, c->tw, c->th, 0, 0);
+	XCopyArea(dpy, dc.drawable, barwin, dc.gc, 0, 0, sw, bh, 0, 0);
 	XSync(dpy, False);
 }
 
