@@ -1,4 +1,4 @@
-/* (C)opyright MMVI Anselm R. Garbe <garbeam at gmail dot com>
+/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  *
  * dynamic window manager is designed like any other X client as well. It is
@@ -43,7 +43,7 @@
 enum { NetSupported, NetWMName, NetLast };		/* EWMH atoms */
 enum { WMProtocols, WMDelete, WMLast };			/* default atoms */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
-enum { ColFG, ColBG, ColLast };				/* color */
+enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
 
 typedef enum {
 	TopLeft, TopRight, BotLeft, BotRight
@@ -66,7 +66,6 @@ typedef struct {
 	int x, y, w, h;
 	unsigned long norm[ColLast];
 	unsigned long sel[ColLast];
-	unsigned long status[ColLast];
 	Drawable drawable;
 	Fnt font;
 	GC gc;
@@ -78,7 +77,6 @@ struct Client {
 	int proto;
 	int x, y, w, h;
 	int rx, ry, rw, rh; /* revert geometry */
-	int tx, ty, tw, th; /* title window geometry */
 	int basew, baseh, incw, inch, maxw, maxh, minw, minh;
 	long flags; 
 	unsigned int border;
@@ -88,15 +86,15 @@ struct Client {
 	Client *prev;
 	Client *snext;
 	Window win;
-	Window twin;
 };
 
 extern const char *tags[];			/* all tags */
-extern char stext[1024];			/* status text */
-extern int bx, by, bw, bh, bmw;			/* bar geometry, bar mode label width */
+extern char stext[256];				/* status text */
+extern int bh, bmw;				/* bar height, bar mode label width */
 extern int screen, sx, sy, sw, sh;		/* screen geometry */
 extern int wax, way, wah, waw;			/* windowarea geometry */
-extern unsigned int master, ntags, numlockmask;	/* master percent, number of tags, dynamic lock mask */
+extern unsigned int master, nmaster;		/* master percent, number of master clients */
+extern unsigned int ntags, numlockmask;		/* number of tags, dynamic lock mask */
 extern void (*handler[LASTEvent])(XEvent *);	/* event handler */
 extern void (*arrange)(void);			/* arrange function, indicates mode  */
 extern Atom wmatom[WMLast], netatom[NetLast];
@@ -108,23 +106,18 @@ extern Display *dpy;
 extern Window root, barwin;
 
 /* client.c */
-extern void ban(Client *c);			/* ban c from screen */
 extern void configure(Client *c);		/* send synthetic configure event */
 extern void focus(Client *c);			/* focus c, c may be NULL */
 extern Client *getclient(Window w);		/* return client of w */
-extern Client *getctitle(Window w);		/* return client of title window */
 extern void killclient(Arg *arg);		/* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);	/* manage new client */
 extern void resize(Client *c, Bool sizehints, Corner sticky); /* resize c*/
-extern void resizetitle(Client *c);		/* resizes c->twin correctly */
-extern void updatesize(Client *c);			/* update the size structs of c */
+extern void updatesizehints(Client *c);		/* update the size hint variables of c */
 extern void updatetitle(Client *c);		/* update the name of c */
 extern void unmanage(Client *c);		/* destroy c */
 
 /* draw.c */
-extern void drawall(void);			/* draw all visible client titles and the bar */
 extern void drawstatus(void);			/* draw the bar */
-extern void drawtitle(Client *c);		/* draw title of c */
 extern unsigned long getcolor(const char *colstr);	/* return color of colstr */
 extern void setfont(const char *fontstr);	/* set the font for DC */
 extern unsigned int textw(const char *text);	/* return the width of text in px*/
@@ -150,7 +143,6 @@ extern void toggletag(Arg *arg);		/* toggles c tags with arg's index */
 /* util.c */
 extern void *emallocz(unsigned int size);	/* allocates zero-initialized memory, exits on error */
 extern void eprint(const char *errstr, ...);	/* prints errstr and exits with 1 */
-extern void *erealloc(void *ptr, unsigned int size);	/* reallocates memory, exits on error */
 extern void spawn(Arg *arg);			/* forks a new subprocess with to arg's cmd */
 
 /* view.c */
@@ -159,6 +151,7 @@ extern void dofloat(void);			/* arranges all windows floating */
 extern void dotile(void);			/* arranges all windows tiled */
 extern void focusnext(Arg *arg);		/* focuses next visible client, arg is ignored  */
 extern void focusprev(Arg *arg);		/* focuses previous visible client, arg is ignored */
+extern void incnmaster(Arg *arg);		/* increments nmaster with arg's index value */
 extern Bool isvisible(Client *c);		/* returns True if client is visible */
 extern void resizemaster(Arg *arg);		/* resizes the master percent with arg's index value */
 extern void restack(void);			/* restores z layers of all clients */
