@@ -1,4 +1,4 @@
-/* (C)opyright MMVI Anselm R. Garbe <garbeam at gmail dot com>
+/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  */
 #include "dwm.h"
@@ -131,8 +131,20 @@ buttonpress(XEvent *e) {
 				return;
 			}
 		}
-		if((ev->x < x + bmw) && (ev->button == Button1))
-			togglemode(NULL);
+		if(ev->x < x + bmw)
+			switch(ev->button) {
+			case Button1:
+				togglemode(NULL);
+				break;
+			case Button4:
+				a.i = 1;
+				incnmaster(&a);
+				break;
+			case Button5:
+				a.i = -1;
+				incnmaster(&a);
+				break;
+			}
 	}
 	else if((c = getclient(ev->window))) {
 		focus(c);
@@ -184,7 +196,7 @@ configurerequest(XEvent *e) {
 		if(c->isfloat) {
 			resize(c, False, TopLeft);
 			if(!isvisible(c))
-				ban(c);
+				XMoveWindow(dpy, c->win, c->x + 2 * sw, c->y);
 		}
 		else
 			arrange();
@@ -218,25 +230,21 @@ enternotify(XEvent *e) {
 
 	if(ev->mode != NotifyNormal || ev->detail == NotifyInferior)
 		return;
-	if(((c = getclient(ev->window)) || (c = getctitle(ev->window))) && isvisible(c))
+	if((c = getclient(ev->window)) && isvisible(c))
 		focus(c);
 	else if(ev->window == root) {
 		issel = True;
 		XSetInputFocus(dpy, root, RevertToPointerRoot, CurrentTime);
-		drawall();
 	}
 }
 
 static void
 expose(XEvent *e) {
-	Client *c;
 	XExposeEvent *ev = &e->xexpose;
 
 	if(ev->count == 0) {
 		if(barwin == ev->window)
 			drawstatus();
-		else if((c = getctitle(ev->window)))
-			drawtitle(c);
 	}
 }
 
@@ -262,10 +270,8 @@ static void
 leavenotify(XEvent *e) {
 	XCrossingEvent *ev = &e->xcrossing;
 
-	if((ev->window == root) && !ev->same_screen) {
+	if((ev->window == root) && !ev->same_screen)
 		issel = False;
-		drawall();
-	}
 }
 
 static void
@@ -314,13 +320,13 @@ propertynotify(XEvent *e) {
 					arrange();
 				break;
 			case XA_WM_NORMAL_HINTS:
-				updatesize(c);
+				updatesizehints(c);
 				break;
 		}
 		if(ev->atom == XA_WM_NAME || ev->atom == netatom[NetWMName]) {
 			updatetitle(c);
-			resizetitle(c);
-			drawtitle(c);
+			if(c == sel)
+				drawstatus();
 		}
 	}
 }
