@@ -1,4 +1,4 @@
-/* (C)opyright MMVI Anselm R. Garbe <garbeam at gmail dot com>
+/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  */
 #include "dwm.h"
@@ -29,15 +29,6 @@ eprint(const char *errstr, ...) {
 	exit(EXIT_FAILURE);
 }
 
-void *
-erealloc(void *ptr, unsigned int size) {
-	void *res = realloc(ptr, size);
-
-	if(!res)
-		eprint("fatal: could not malloc() %u bytes\n", size);
-	return res;
-}
-
 void
 spawn(Arg *arg) {
 	static char *shell = NULL;
