@@ -1,7 +1,8 @@
-/* (C)opyright MMVI Anselm R. Garbe <garbeam at gmail dot com>
+/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  */
 #include "dwm.h"
+#include <stdio.h>
 
 /* static */
 
@@ -58,7 +59,7 @@ dofloat(void) {
 			resize(c, True, TopLeft);
 		}
 		else
-			ban(c);
+			XMoveWindow(dpy, c->win, c->x + 2 * sw, c->y);
 	}
 	if(!sel || !isvisible(sel)) {
 		for(c = stack; c && !isvisible(c); c = c->snext);
@@ -69,13 +70,16 @@ dofloat(void) {
 
 void
 dotile(void) {
-	unsigned int i, n, mpx, stackw, th;
+	unsigned int i, n, mw, mh, tw, th;
 	Client *c;
 
 	for(n = 0, c = nexttiled(clients); c; c = nexttiled(c->next))
 		n++;
-	mpx = (waw * master) / 1000;
-	stackw = waw - mpx;
+	/* window geoms */
+	mh = (n > nmaster) ? wah / nmaster : wah / (n > 0 ? n : 1);
+	mw = (n > nmaster) ? (waw * master) / 1000 : waw;
+	th = (n > nmaster) ? wah / (n - nmaster) : 0;
+	tw = waw - mw;
 
 	for(i = 0, c = clients; c; c = c->next)
 		if(isvisible(c)) {
@@ -86,20 +90,16 @@ dotile(void) {
 			c->ismax = False;
 			c->x = wax;
 			c->y = way;
-			if(n == 1) { /* only 1 window */
-				c->w = waw - 2 * BORDERPX;
-				c->h = wah - 2 * BORDERPX;
-			}
-			else if(i == 0) { /* master window */
-				c->w = mpx - 2 * BORDERPX;
-				c->h = wah - 2 * BORDERPX;
-				th = wah / (n - 1);
+			if(i < nmaster) {
+				c->y += i * mh;
+				c->w = mw - 2 * BORDERPX;
+				c->h = mh - 2 * BORDERPX;
 			}
 			else {  /* tile window */
-				c->x += mpx;
-				c->w = stackw - 2 * BORDERPX;
+				c->x += mw;
+				c->w = tw - 2 * BORDERPX;
 				if(th > bh) {
-					c->y += (i - 1) * th;
+					c->y += (i - nmaster) * th;
 					c->h = th - 2 * BORDERPX;
 				}
 				else /* fallback if th < bh */
@@ -109,8 +109,7 @@ dotile(void) {
 			i++;
 		}
 		else
-			ban(c);
-
+			XMoveWindow(dpy, c->win, c->x + 2 * sw, c->y);
 	if(!sel || !isvisible(sel)) {
 		for(c = stack; c && !isvisible(c); c = c->snext);
 		focus(c);
@@ -148,6 +147,17 @@ focusprev(Arg *arg) {
 	}
 }
 
+void
+incnmaster(Arg *arg) {
+	if((arrange == dofloat) || (nmaster + arg->i < 1) || (wah / (nmaster + arg->i) < bh))
+		return;
+	nmaster += arg->i;
+	if(sel)
+		arrange();
+	else
+		drawstatus();
+}
+
 Bool
 isvisible(Client *c) {
 	unsigned int i;
@@ -175,27 +185,20 @@ restack(void) {
 	Client *c;
 	XEvent ev;
 
-	if(!sel) {
-		drawstatus();
+	drawstatus();
+	if(!sel)
 		return;
-	}
-	if(sel->isfloat || arrange == dofloat) {
+	if(sel->isfloat || arrange == dofloat)
 		XRaiseWindow(dpy, sel->win);
-		XRaiseWindow(dpy, sel->twin);
-	}
 	if(arrange != dofloat) {
-		if(!sel->isfloat) {
-			XLowerWindow(dpy, sel->twin);
+		if(!sel->isfloat)
 			XLowerWindow(dpy, sel->win);
-		}
 		for(c = nexttiled(clients); c; c = nexttiled(c->next)) {
 			if(c == sel)
 				continue;
-			XLowerWindow(dpy, c->twin);
 			XLowerWindow(dpy, c->win);
 		}
 	}
-	drawall();
 	XSync(dpy, False);
 	while(XCheckMaskEvent(dpy, EnterWindowMask, &ev));
 }
@@ -250,11 +253,9 @@ zoom(Arg *arg) {
 		togglemax(sel);
 		return;
 	}
-	for(n = 0, c = clients; c; c = c->next)
-		if(isvisible(c) && !c->isfloat)
-			n++;
-	if(n < 2 || (arrange == dofloat))
-		return;
+	for(n = 0, c = nexttiled(clients); c; c = nexttiled(c->next))
+		n++;
+
 	if((c = sel) == nexttiled(clients))
 		if(!(c = nexttiled(c->next)))
 			return;
